
# Slot: from_schema


id of the schema that defined the element

URI: [linkml:from_schema](https://w3id.org/linkml/from_schema)


## Domain and Range

[Element](Element.md) &#8594;  <sub>0..1</sub> [Uri](Uri.md)

## Parents


## Children


## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [CommonMetadata](CommonMetadata.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [EnumDefinition](EnumDefinition.md)
 * [PermissibleValue](PermissibleValue.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | skos:inScheme |

